==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/pages/entry/ViewEntryUpperToolbar.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/pages/entry/ViewEntryUpperToolbar.es", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/button', '@frontend-taglib-clay$clayui/button/lib/Group', '@frontend-taglib-clay$clayui/tooltip', 'frontend-js-react-web$react', 'app-builder-web$react-router-dom', '../../AppContext.es', '../../components/upper-toolbar/UpperToolbar.es', '../../utils/lang.es', './PermissionsContext.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _button = require("@frontend-taglib-clay$clayui/button");

  var _Group = _interopRequireDefault(require("@frontend-taglib-clay$clayui/button/lib/Group"));

  var _tooltip = require("@frontend-taglib-clay$clayui/tooltip");

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _reactRouterDom = require("app-builder-web$react-router-dom");

  var _AppContext = require("../../AppContext.es");

  var _UpperToolbar = _interopRequireDefault(require("../../components/upper-toolbar/UpperToolbar.es"));

  var _lang = _interopRequireDefault(require("../../utils/lang.es"));

  var _PermissionsContext = require("./PermissionsContext.es");

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    } else {
      var newObj = {};if (obj != null) {
        for (var key in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};if (desc.get || desc.set) {
              Object.defineProperty(newObj, key, desc);
            } else {
              newObj[key] = obj[key];
            }
          }
        }
      }newObj["default"] = obj;return newObj;
    }
  }

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  /**
   * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
   *
   * This library is free software; you can redistribute it and/or modify it under
   * the terms of the GNU Lesser General Public License as published by the Free
   * Software Foundation; either version 2.1 of the License, or (at your option)
   * any later version.
   *
   * This library is distributed in the hope that it will be useful, but WITHOUT
   * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
   * details.
   */
  var _default = (0, _reactRouterDom.withRouter)(function (_ref) {
    var onDelete = _ref.onDelete,
        onEdit = _ref.onEdit,
        onNext = _ref.onNext,
        onPrev = _ref.onPrev,
        page = _ref.page,
        total = _ref.total;

    var _useContext = (0, _react.useContext)(_AppContext.AppContext),
        showFormView = _useContext.showFormView;

    var actionIds = (0, _react.useContext)(_PermissionsContext.PermissionsContext);
    var hasDeletePermission = actionIds.includes(_PermissionsContext.ACTIONS.DELETE_DATA_RECORD);
    var hasEditPermission = actionIds.includes(_PermissionsContext.ACTIONS.UPDATE_DATA_RECORD);
    return _react["default"].createElement(_UpperToolbar["default"], null, _react["default"].createElement(_UpperToolbar["default"].Item, {
      className: "text-left",
      expand: true
    }, _react["default"].createElement("label", null, _lang["default"].sub(Liferay.Language.get('x-of-x-entries'), [page, total]))), _react["default"].createElement(_UpperToolbar["default"].Group, null, _react["default"].createElement(_tooltip.ClayTooltipProvider, null, _react["default"].createElement(_Group["default"], null, _react["default"].createElement(_button.ClayButtonWithIcon, {
      "data-tooltip-align": "bottom",
      "data-tooltip-delay": "200",
      disabled: page === 1,
      displayType: "secondary",
      onClick: onPrev,
      small: true,
      symbol: "angle-left",
      title: Liferay.Language.get('previous-entry')
    }), _react["default"].createElement(_button.ClayButtonWithIcon, {
      "data-tooltip-align": "bottom",
      "data-tooltip-delay": "200",
      disabled: page === total,
      displayType: "secondary",
      onClick: onNext,
      small: true,
      symbol: "angle-right",
      title: Liferay.Language.get('next-entry')
    })))), showFormView && _react["default"].createElement(_UpperToolbar["default"].Group, null, hasDeletePermission && _react["default"].createElement(_UpperToolbar["default"].Button, {
      displayType: "secondary",
      onClick: onDelete
    }, Liferay.Language.get('delete')), hasEditPermission && _react["default"].createElement(_UpperToolbar["default"].Button, {
      onClick: onEdit
    }, Liferay.Language.get('edit'))));
  });

  exports["default"] = _default;
  //# sourceMappingURL=ViewEntryUpperToolbar.es.js.map
});
//# sourceMappingURL=ViewEntryUpperToolbar.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/pages/entry/ViewEntryUpperToolbar.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/pages/entry/ViewEntryUpperToolbar.es", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/button', '@frontend-taglib-clay$clayui/button/lib/Group', '@frontend-taglib-clay$clayui/tooltip', 'frontend-js-react-web$react', 'app-builder-web$react-router-dom', '../../AppContext.es', '../../components/upper-toolbar/UpperToolbar.es', '../../utils/lang.es', './PermissionsContext.es'], function (module, exports, require) {
  var define = undefined;
  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _button = require("@frontend-taglib-clay$clayui/button");

  var _Group = _interopRequireDefault(require("@frontend-taglib-clay$clayui/button/lib/Group"));

  var _tooltip = require("@frontend-taglib-clay$clayui/tooltip");

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _reactRouterDom = require("app-builder-web$react-router-dom");

  var _AppContext = require("../../AppContext.es");

  var _UpperToolbar = _interopRequireDefault(require("../../components/upper-toolbar/UpperToolbar.es"));

  var _lang = _interopRequireDefault(require("../../utils/lang.es"));

  var _PermissionsContext = require("./PermissionsContext.es");

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  /**
   * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
   *
   * This library is free software; you can redistribute it and/or modify it under
   * the terms of the GNU Lesser General Public License as published by the Free
   * Software Foundation; either version 2.1 of the License, or (at your option)
   * any later version.
   *
   * This library is distributed in the hope that it will be useful, but WITHOUT
   * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
   * details.
   */
  var _default = (0, _reactRouterDom.withRouter)(function (_ref) {
    var onDelete = _ref.onDelete,
        onEdit = _ref.onEdit,
        onNext = _ref.onNext,
        onPrev = _ref.onPrev,
        page = _ref.page,
        total = _ref.total;

    var _useContext = (0, _react.useContext)(_AppContext.AppContext),
        showFormView = _useContext.showFormView;

    var actionIds = (0, _react.useContext)(_PermissionsContext.PermissionsContext);
    var hasDeletePermission = actionIds.includes(_PermissionsContext.ACTIONS.DELETE_DATA_RECORD);
    var hasEditPermission = actionIds.includes(_PermissionsContext.ACTIONS.UPDATE_DATA_RECORD);
    return _react["default"].createElement(_UpperToolbar["default"], null, _react["default"].createElement(_UpperToolbar["default"].Item, {
      className: "text-left",
      expand: true
    }, _react["default"].createElement("label", null, _lang["default"].sub(Liferay.Language.get('x-of-x-entries'), [page, total]))), _react["default"].createElement(_UpperToolbar["default"].Group, null, _react["default"].createElement(_tooltip.ClayTooltipProvider, null, _react["default"].createElement(_Group["default"], null, _react["default"].createElement(_button.ClayButtonWithIcon, {
      "data-tooltip-align": "bottom",
      "data-tooltip-delay": "200",
      disabled: page === 1,
      displayType: "secondary",
      onClick: onPrev,
      small: true,
      symbol: "angle-left",
      title: Liferay.Language.get('previous-entry')
    }), _react["default"].createElement(_button.ClayButtonWithIcon, {
      "data-tooltip-align": "bottom",
      "data-tooltip-delay": "200",
      disabled: page === total,
      displayType: "secondary",
      onClick: onNext,
      small: true,
      symbol: "angle-right",
      title: Liferay.Language.get('next-entry')
    })))), showFormView && _react["default"].createElement(_UpperToolbar["default"].Group, null, hasDeletePermission && _react["default"].createElement(_UpperToolbar["default"].Button, {
      displayType: "secondary",
      onClick: onDelete
    }, Liferay.Language.get('delete')), hasEditPermission && _react["default"].createElement(_UpperToolbar["default"].Button, {
      onClick: onEdit
    }, Liferay.Language.get('edit'))));
  });

  exports["default"] = _default;
  //# sourceMappingURL=ViewEntryUpperToolbar.es.js.map
});
//# sourceMappingURL=ViewEntryUpperToolbar.es.js.map
